/**
* 
* @author José Rojel
* 
*	Esta clase implementa los elementos gráficos y sus respectivos listeners que se
*	ocuparán para actualizar la database y refresar el ShowerPanel a través de su atributo
*	privado Administrador, el cual coincide con el instanciado en la clase Test.
*	
*/

import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.IOException;
import java.util.*;
import java.util.List;

import javax.swing.*;

public class RegistererPanel extends JPanel {
	
	private JTextPane km_pane;
	private JTextPane fuel_pane;
	private JTextPane pass_pane;
	private JComboBox percep; 
	private Administrador admin;
	final static String REGISTERFILE = "./registros.csv";

	public RegistererPanel(JPanel cards) {
		
		this.setLayout(new BoxLayout(this, BoxLayout.Y_AXIS));
		CardLayout card_changer = (CardLayout)(cards.getLayout());
		
		JLabel panel_name = new JLabel(" Panel de Registro ");
		panel_name.setHorizontalAlignment(SwingConstants.CENTER);
		panel_name.setFont(new Font("Dialog", Font.BOLD, 18));
		panel_name.setAlignmentX(Component.CENTER_ALIGNMENT);
		
		JButton btnBack = new JButton("Back");
		btnBack.setFont(new Font("Arial", Font.PLAIN, 10));
		btnBack.setAlignmentX(Component.RIGHT_ALIGNMENT);
		
		JLabel km_lbl = new JLabel("Kilómetros recorridos");
		km_lbl.setHorizontalAlignment(SwingConstants.CENTER);
		km_lbl.setAlignmentX(Component.CENTER_ALIGNMENT);
		
		JLabel fuel_lbl = new JLabel("Gasto en combustible");
		fuel_lbl.setHorizontalAlignment(SwingConstants.CENTER);
		fuel_lbl.setAlignmentX(Component.CENTER_ALIGNMENT);
		
		JLabel pass_lbl = new JLabel("Cantidad de pasajeros");
		pass_lbl.setHorizontalAlignment(SwingConstants.CENTER);
		pass_lbl.setAlignmentX(Component.CENTER_ALIGNMENT);
		
		JLabel day_lbl = new JLabel("Percepción del día");
		day_lbl.setHorizontalAlignment(SwingConstants.CENTER);
		day_lbl.setAlignmentX(Component.CENTER_ALIGNMENT);
		
		km_pane = new JTextPane();
		km_pane.setPreferredSize(new Dimension(100, 20));
		km_pane.setAlignmentX(Component.CENTER_ALIGNMENT);
		km_pane.setPreferredSize(new Dimension(150, 20));
		km_pane.setMinimumSize(new Dimension(150, 20));
		km_pane.setMaximumSize(new Dimension(150, 20));
		
		fuel_pane = new JTextPane();
		fuel_pane.setPreferredSize(new Dimension(100, 20));
		fuel_pane.setAlignmentX(Component.CENTER_ALIGNMENT);
		fuel_pane.setPreferredSize(new Dimension(150, 20));
		fuel_pane.setMinimumSize(new Dimension(150, 20));
		fuel_pane.setMaximumSize(new Dimension(150, 20));
		
		pass_pane = new JTextPane();
		pass_pane.setPreferredSize(new Dimension(150, 20));
		pass_pane.setMinimumSize(new Dimension(150, 20));
		pass_pane.setMaximumSize(new Dimension(150, 20));
		pass_pane.setAlignmentX(Component.CENTER_ALIGNMENT);
		
		percep = new JComboBox();
		percep.setFont(new Font("Dialog", Font.PLAIN, 12));
		percep.setModel(new DefaultComboBoxModel(new String[] {"Excelente", "Bien", "Regular", "Deficiente", "Pésimo"}));
		percep.setSelectedIndex(-1);
		percep.setPreferredSize(new Dimension(150,20));
		percep.setMinimumSize(new Dimension(150, 20));
		percep.setMaximumSize(new Dimension(150, 20));
		percep.setAlignmentX(Component.CENTER_ALIGNMENT);
		
		JButton register_btn = new JButton("Registrar");
		register_btn.setFont(new Font("Dialog", Font.BOLD, 15));
		register_btn.setAlignmentX(Component.CENTER_ALIGNMENT);
		register_btn.addActionListener(new ActionListener(){
			
			// Evento para el botón de registro
	        @Override
	        public void actionPerformed(ActionEvent arg0) {
	        	if(soloNumeros()) {
	        		CSVWriter writer = new CSVWriter(REGISTERFILE);
	        		try {
						writer.makeFile();
					} catch (IOException e) {
						e.printStackTrace();
					}
	        		try {
						writer.printSomething(getAnswer());
					} catch (IOException e) {
						e.printStackTrace();
					}
	        		try {
						admin.updateShower();
					} catch (NumberFormatException | IOException e) {
						// TODO Auto-generated catch block
						e.printStackTrace();
					}
	        		JOptionPane.showMessageDialog(null, "Sus datos se han registrado con éxito!");
	        		card_changer.show(cards,"Panel de Entrada");
	        		resetPanes();
	        	}
	        }
	    });
		
		JButton back_btn = new JButton("Back");
		back_btn.setFont(new Font("Dialog", Font.PLAIN, 10));
		back_btn.setAlignmentX(Component.CENTER_ALIGNMENT);
		back_btn.setPreferredSize(new Dimension(60,20));
		back_btn.setMinimumSize(new Dimension(60, 20));
		back_btn.setMaximumSize(new Dimension(60, 20));
		
		// Evento para el botón Back
		back_btn.addActionListener(new ActionListener() {

	        @Override
	        public void actionPerformed(ActionEvent arg0) {
	        	card_changer.show(cards, "Panel de Entrada");
	        }
	    });
		
		// Agregar elementos al Panel

		// 70 Pixeles vacios al principio
		this.add(Box.createRigidArea(new Dimension(0,40)));
		// Mensaje de Bienvenida
		this.add(panel_name);
		this.add(Box.createRigidArea(new Dimension(0,40)));
		
		this.add(km_lbl);
		this.add(Box.createRigidArea(new Dimension(0,10)));
		this.add(km_pane);
		this.add(Box.createRigidArea(new Dimension(0,15)));
		
		this.add(fuel_lbl);
		this.add(Box.createRigidArea(new Dimension(0,10)));
		this.add(fuel_pane);
		this.add(Box.createRigidArea(new Dimension(0,15)));

		this.add(pass_lbl);
		this.add(Box.createRigidArea(new Dimension(0,10)));
		this.add(pass_pane);
		this.add(Box.createRigidArea(new Dimension(0,15)));
		
		this.add(day_lbl);
		this.add(Box.createRigidArea(new Dimension(0,10)));
		this.add(percep);
		this.add(Box.createRigidArea(new Dimension(0,15)));
		
		this.add(Box.createRigidArea(new Dimension(0,25)));
		this.add(register_btn);
		
		this.add(Box.createRigidArea(new Dimension(0,10)));
		this.add(back_btn);
	}
	
	public boolean soloNumeros() {
		if(!admin.checkText(km_pane.getText())) {
			JOptionPane.showMessageDialog(null, "Error en [km] recorridos", "Error",JOptionPane.ERROR_MESSAGE);
			return false;
		} else if(!admin.checkText(fuel_pane.getText())) {
			JOptionPane.showMessageDialog(null, "Error en [$] de combustible", "Error",JOptionPane.ERROR_MESSAGE);
			return false;
		} else if(!admin.checkText(pass_pane.getText())) {
			JOptionPane.showMessageDialog(null, "Error en cantidad de pasajeros", "Error",JOptionPane.ERROR_MESSAGE);
			return false;
		} else if(percep.getSelectedIndex()==-1) {
			JOptionPane.showMessageDialog(null, "Olvidó poner su percepción de hoy :)", "Error",JOptionPane.ERROR_MESSAGE);
			return false;
		}
		
		else {
			return true;
		}
	}
	
	public ArrayList<String> getAnswer() throws IOException {
		ArrayList<String> resp = new ArrayList<String>();
		CSVReader reader = new CSVReader(REGISTERFILE);
		resp.add(String.valueOf(reader.lineNumbers()));
		resp.add(km_pane.getText());
		resp.add(fuel_pane.getText());
		resp.add(pass_pane.getText());
		resp.add(String.valueOf(2-percep.getSelectedIndex()));
		
		return resp;
	}
	
	public void resetPanes() {
		km_pane.setText(null);
		fuel_pane.setText(null);
		pass_pane.setText(null);
		percep.setSelectedIndex(-1);
	}
	
	public void setAdministrador(Administrador admin_) {
		admin = admin_;
	}
	

}
